Package: dimensio
Title: Multivariate Data Analysis
Version: 0.14.2
Authors@R: c(
    person("Nicolas", "Frerebeau", , "nicolas.frerebeau@u-bordeaux-montaigne.fr", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-5759-4944")),
    person("Jean-Baptiste", "Fourvel", , "jean-baptiste.fourvel@univ-amu.fr", role = "ctb",
           comment = c(ORCID = "0000-0002-1061-4642")),
    person("Camille", "Thabard", , "camille.thabard@univ-tlse2.fr", role = "ctb",
           comment = c(ORCID = "0000-0002-3196-7658")),
    person("Brice", "Lebrun", role = "art",
           comment = c(ORCID = "0000-0001-7503-8685", "Logo designer")),
    person("Université Bordeaux Montaigne", role = "fnd",
           comment = c(ROR = "03pbgwk21")),
    person("CNRS", role = "fnd",
           comment = c(ROR = "02feahw73"))
  )
Maintainer: Nicolas Frerebeau <nicolas.frerebeau@u-bordeaux-montaigne.fr>
Description: Simple Principal Components Analysis (PCA) and (Multiple)
    Correspondence Analysis (CA) based on the Singular Value Decomposition
    (SVD). This package provides S4 classes and methods to compute,
    extract, summarize and visualize results of multivariate data
    analysis. It also includes methods for partial bootstrap validation
    described in Greenacre (1984, ISBN: 978-0-12-299050-2) and Lebart et
    al. (2006, ISBN: 978-2-10-049616-7).
License: GPL (>= 3)
URL: https://codeberg.org/tesselle/dimensio,
        https://packages.tesselle.org/dimensio/,
        https://tesselle.r-universe.dev/dimensio
BugReports: https://codeberg.org/tesselle/dimensio/issues
Depends: R (>= 3.5)
Imports: arkhe (>= 1.11.0), graphics, grDevices, khroma (>= 1.17.0),
        methods, utils
Suggests: fontquiver, knitr, markdown, rsvg, svglite, tinysnapshot (>=
        0.2.0), tinytest
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
X-schema.org-isPartOf: https://www.tesselle.org
X-schema.org-keywords: data-analysis, multivariate-analysis, r-package
Collate: 'AllClasses.R' 'AllGenerics.R' 'annotations.R' 'augment.R'
        'biplot.R' 'bootstrap.R' 'ca.R' 'coerce.R' 'data.R'
        'dimensio-defunct.R' 'dimensio-deprecated.R'
        'dimensio-internal.R' 'dimensio-package.R' 'export.R'
        'get_contributions.R' 'get_coordinates.R' 'get_correlations.R'
        'get_cos2.R' 'get_data.R' 'get_distances.R' 'get_eigenvalues.R'
        'get_inertia.R' 'get_variance.R' 'mca.R' 'mutators.R' 'pca.R'
        'pcoa.R' 'plot.R' 'predict.R' 'reexport.R' 'screeplot.R'
        'show.R' 'subset.R' 'summary.R' 'svd.R' 'tidy.R' 'tools.R'
        'viz_contributions.R' 'viz_coordinates.R' 'viz_cos2.R'
        'viz_ellipse.R' 'viz_hull.R' 'wrap_ellipses.R' 'wrap_hull.R'
        'zzz.R'
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-22 14:08:48 UTC; nfrerebeau
Author: Nicolas Frerebeau [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-5759-4944>),
  Jean-Baptiste Fourvel [ctb] (ORCID:
    <https://orcid.org/0000-0002-1061-4642>),
  Camille Thabard [ctb] (ORCID: <https://orcid.org/0000-0002-3196-7658>),
  Brice Lebrun [art] (ORCID: <https://orcid.org/0000-0001-7503-8685>,
    Logo designer),
  Université Bordeaux Montaigne [fnd] (ROR: <https://ror.org/03pbgwk21>),
  CNRS [fnd] (ROR: <https://ror.org/02feahw73>)
Repository: CRAN
Date/Publication: 2026-06-22 15:50:12 UTC
Built: R 4.6.0; ; 2026-06-22 19:47:14 UTC; unix
