# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,MultivariateSummary)
S3method(as.list,MultivariateAnalysis)
S3method(as.list,MultivariateResults)
S3method(biplot,CA)
S3method(biplot,PCA)
S3method(colnames,MultivariateAnalysis)
S3method(dim,MultivariateAnalysis)
S3method(dimnames,MultivariateAnalysis)
S3method(plot,PCOA)
S3method(rownames,MultivariateAnalysis)
S3method(screeplot,MultivariateAnalysis)
S3method(screeplot,PCOA)
S3method(summary,CA)
S3method(summary,PCA)
export(color)
export(label)
export(palette_color_continuous)
export(palette_color_discrete)
export(palette_color_picker)
export(palette_line)
export(palette_shape)
export(palette_size_sequential)
export(plot_columns)
export(plot_contributions)
export(plot_cos2)
export(plot_individuals)
export(plot_rows)
export(plot_variables)
export(plot_variance)
exportClasses(CA)
exportClasses(MCA)
exportClasses(PCA)
exportClasses(PCOA)
exportMethods("[[")
exportMethods(as.data.frame)
exportMethods(augment)
exportMethods(biplot)
exportMethods(bootstrap)
exportMethods(burt)
exportMethods(ca)
exportMethods(cdt)
exportMethods(colnames)
exportMethods(describe)
exportMethods(dim)
exportMethods(dimnames)
exportMethods(export)
exportMethods(get_contributions)
exportMethods(get_coordinates)
exportMethods(get_correlations)
exportMethods(get_cos2)
exportMethods(get_data)
exportMethods(get_distances)
exportMethods(get_eigenvalues)
exportMethods(get_inertia)
exportMethods(get_replications)
exportMethods(get_variance)
exportMethods(mca)
exportMethods(pca)
exportMethods(pcoa)
exportMethods(plot)
exportMethods(predict)
exportMethods(rownames)
exportMethods(screeplot)
exportMethods(summary)
exportMethods(tidy)
exportMethods(viz_columns)
exportMethods(viz_confidence)
exportMethods(viz_contributions)
exportMethods(viz_cos2)
exportMethods(viz_ellipses)
exportMethods(viz_hull)
exportMethods(viz_individuals)
exportMethods(viz_rows)
exportMethods(viz_tolerance)
exportMethods(viz_variables)
exportMethods(wrap_confidence)
exportMethods(wrap_hull)
exportMethods(wrap_tolerance)
import(arkhe)
import(methods)
importFrom(grDevices,adjustcolor)
importFrom(grDevices,as.raster)
importFrom(grDevices,chull)
importFrom(grDevices,colorRamp)
importFrom(grDevices,hcl.colors)
importFrom(grDevices,rgb)
importFrom(khroma,color)
importFrom(khroma,palette_color_continuous)
importFrom(khroma,palette_color_discrete)
importFrom(khroma,palette_color_picker)
importFrom(khroma,palette_line)
importFrom(khroma,palette_shape)
importFrom(khroma,palette_size_sequential)
importFrom(stats,aggregate)
importFrom(stats,approx)
importFrom(stats,cmdscale)
importFrom(stats,cov)
importFrom(stats,na.omit)
importFrom(stats,qchisq)
importFrom(stats,qf)
importFrom(stats,rmultinom)
importFrom(stats,runif)
importFrom(utils,capture.output)
importFrom(utils,modifyList)
importFrom(utils,stack)
importFrom(utils,tail)
importMethodsFrom(arkhe,bootstrap)
importMethodsFrom(arkhe,describe)
